@@ -2,11 +2,14 @@ package TestApp;
 
 use strict;
 use Catalyst;
+use File::Spec::Functions;
+use FindBin;
 
 our $VERSION = '0.01';
 
 TestApp->config(
     name => 'TestApp',
+    debug => 1,
 );
 
 my @plugins = qw/Static::Simple/;
@@ -44,4 +47,20 @@ sub subtest2 : Local {
     $c->res->output( 'subtest2 ok' );
 }
 
+sub serve_static : Local {
+    my ( $self, $c ) = @_;
+    
+    my $file = catfile( $FindBin::Bin, 'lib', 'TestApp.pm' );
+    
+    $c->serve_static_file( $file );
+}
+
+sub serve_static_404 : Local {
+    my ( $self, $c ) = @_;
+    
+    my $file = catfile( $FindBin::Bin, 'lib', 'foo.pm' );
+    
+    $c->serve_static_file( $file );
+}
+
 1;
